@@ -19,7 +19,7 @@
     "clinical trial registers when using their information. Call\n",
     "ctrOpenSearchPagesInBrowser(copyright = TRUE) and visit\n",
     "https://www.clinicaltrialsregister.eu/disclaimer.html\n",
-    "https://clinicaltrials.gov/ct2/about-site/terms-conditions#Use\n",
+    "https://classic.clinicaltrials.gov/ct2/about-site/terms-conditions#Use\n",
     "https://www.isrctn.com/page/faqs#usingISRCTN\n",
     "https://euclinicaltrials.eu/about-this-website/\n",
     "\nPlease cite this package, see citation(\"ctrdata\").\n",
